@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* NetworkManager Wireless Applet -- Display wireless access points and allow user control
+/* NetworkManager Applet -- allow user control over networking
  *
  * Dan Williams <dcbw@redhat.com>
  *
@@ -46,10 +46,11 @@
 #include "ap-menu-item.h"
 #include "utils.h"
 #include "nm-wifi-dialog.h"
+#include "nm-ui-utils.h"
 
 #define ACTIVE_AP_TAG "active-ap"
 
-static void wireless_dialog_response_cb (GtkDialog *dialog, gint response, gpointer user_data);
+static void wifi_dialog_response_cb (GtkDialog *dialog, gint response, gpointer user_data);
 
 static void nag_dialog_response_cb (GtkDialog *nag_dialog, gint response, gpointer user_data);
 
@@ -80,7 +81,7 @@ applet_wifi_connect_to_hidden_network (NMApplet *applet)
 	dialog = nma_wifi_dialog_new_for_other (applet->nm_client, applet->settings);
 	if (dialog) {
 		g_signal_connect (dialog, "response",
-		                  G_CALLBACK (wireless_dialog_response_cb),
+		                  G_CALLBACK (wifi_dialog_response_cb),
 		                  applet);
 		show_ignore_focus_stealing_prevention (dialog);
 	}
@@ -94,7 +95,7 @@ nma_menu_add_hidden_network_item (GtkWidget *menu, NMApplet *applet)
 	GtkWidget *label;
 
 	menu_item = gtk_menu_item_new ();
-	label = gtk_label_new_with_mnemonic (_("_Connect to Hidden Wireless Network..."));
+	label = gtk_label_new_with_mnemonic (_("_Connect to Hidden Wi-Fi Network..."));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_container_add (GTK_CONTAINER (menu_item), label);
 	gtk_widget_show_all (menu_item);
@@ -110,7 +111,7 @@ applet_wifi_can_create_wifi_network (NMApplet *applet)
 	gboolean disabled, allowed = FALSE;
 	NMClientPermissionResult perm;
 
-	/* FIXME: check WIFI_SHARE_PROTECTED too, and make the wireless dialog
+	/* FIXME: check WIFI_SHARE_PROTECTED too, and make the wifi dialog
 	 * handle the permissions as well so that admins can restrict open network
 	 * creation separately from protected network creation.
 	 */
@@ -131,7 +132,7 @@ applet_wifi_create_wifi_network (NMApplet *applet)
 	dialog = nma_wifi_dialog_new_for_create (applet->nm_client, applet->settings);
 	if (dialog) {
 		g_signal_connect (dialog, "response",
-		                  G_CALLBACK (wireless_dialog_response_cb),
+		                  G_CALLBACK (wifi_dialog_response_cb),
 		                  applet);
 		show_ignore_focus_stealing_prevention (dialog);
 	}
@@ -145,7 +146,7 @@ nma_menu_add_create_network_item (GtkWidget *menu, NMApplet *applet)
 	GtkWidget *label;
 
 	menu_item = gtk_menu_item_new ();
-	label = gtk_label_new_with_mnemonic (_("Create _New Wireless Network..."));
+	label = gtk_label_new_with_mnemonic (_("Create _New Wi-Fi Network..."));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_container_add (GTK_CONTAINER (menu_item), label);
 	gtk_widget_show_all (menu_item);
@@ -225,12 +226,12 @@ typedef struct {
 	NMDeviceWifi *device;
 	NMAccessPoint *ap;
 	NMConnection *connection;
-} WirelessMenuItemInfo;
+} WifiMenuItemInfo;
 
 static void
-wireless_menu_item_info_destroy (gpointer data)
+wifi_menu_item_info_destroy (gpointer data)
 {
-	WirelessMenuItemInfo *info = (WirelessMenuItemInfo *) data;
+	WifiMenuItemInfo *info = (WifiMenuItemInfo *) data;
 
 	g_object_unref (G_OBJECT (info->device));
 	g_object_unref (G_OBJECT (info->ap));
@@ -238,7 +239,7 @@ wireless_menu_item_info_destroy (gpointer data)
 	if (info->connection)
 		g_object_unref (G_OBJECT (info->connection));
 
-	g_slice_free (WirelessMenuItemInfo, data);
+	g_slice_free (WifiMenuItemInfo, data);
 }
 
 /*
@@ -483,12 +484,12 @@ _do_new_auto_connection (NMApplet *applet,
 }
 
 static gboolean
-wireless_new_auto_connection (NMDevice *device,
-                              gpointer dclass_data,
-                              AppletNewAutoConnectionCallback callback,
-                              gpointer callback_data)
+wifi_new_auto_connection (NMDevice *device,
+                          gpointer dclass_data,
+                          AppletNewAutoConnectionCallback callback,
+                          gpointer callback_data)
 {
-	WirelessMenuItemInfo *info = (WirelessMenuItemInfo *) dclass_data;
+	WifiMenuItemInfo *info = (WifiMenuItemInfo *) dclass_data;
 
 	g_return_val_if_fail (device != NULL, FALSE);
 	g_return_val_if_fail (info->ap != NULL, FALSE);
@@ -499,9 +500,9 @@ wireless_new_auto_connection (NMDevice *device,
 
 
 static void
-wireless_menu_item_activate (GtkMenuItem *item, gpointer user_data)
+wifi_menu_item_activate (GtkMenuItem *item, gpointer user_data)
 {
-	WirelessMenuItemInfo *info = (WirelessMenuItemInfo *) user_data;
+	WifiMenuItemInfo *info = (WifiMenuItemInfo *) user_data;
 	const char *specific_object = NULL;
 
 	if (info->ap)
@@ -550,7 +551,7 @@ create_new_ap_item (NMDeviceWifi *device,
                     GSList *connections,
                     NMApplet *applet)
 {
-	WirelessMenuItemInfo *info;
+	WifiMenuItemInfo *info;
 	GSList *iter;
 	NMNetworkMenuItem *item = NULL;
 	GSList *dev_connections = NULL;
@@ -592,16 +593,16 @@ create_new_ap_item (NMDeviceWifi *device,
 			s_con = nm_connection_get_setting_connection (connection);
 			subitem = gtk_menu_item_new_with_label (nm_setting_connection_get_id (s_con));
 
-			info = g_slice_new0 (WirelessMenuItemInfo);
+			info = g_slice_new0 (WifiMenuItemInfo);
 			info->applet = applet;
 			info->device = g_object_ref (G_OBJECT (device));
 			info->ap = g_object_ref (G_OBJECT (ap));
 			info->connection = g_object_ref (G_OBJECT (connection));
 
 			g_signal_connect_data (subitem, "activate",
-			                       G_CALLBACK (wireless_menu_item_activate),
+			                       G_CALLBACK (wifi_menu_item_activate),
 			                       info,
-			                       (GClosureNotify) wireless_menu_item_info_destroy, 0);
+			                       (GClosureNotify) wifi_menu_item_info_destroy, 0);
 
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), GTK_WIDGET (subitem));
 		}
@@ -610,7 +611,7 @@ create_new_ap_item (NMDeviceWifi *device,
 	} else {
 		NMConnection *connection;
 
-		info = g_slice_new0 (WirelessMenuItemInfo);
+		info = g_slice_new0 (WifiMenuItemInfo);
 		info->applet = applet;
 		info->device = g_object_ref (G_OBJECT (device));
 		info->ap = g_object_ref (G_OBJECT (ap));
@@ -622,9 +623,9 @@ create_new_ap_item (NMDeviceWifi *device,
 
 		g_signal_connect_data (GTK_WIDGET (item),
 		                       "activate",
-		                       G_CALLBACK (wireless_menu_item_activate),
+		                       G_CALLBACK (wifi_menu_item_activate),
 		                       info,
-		                       (GClosureNotify) wireless_menu_item_info_destroy,
+		                       (GClosureNotify) wifi_menu_item_info_destroy,
 		                       0);
 	}
 
@@ -757,11 +758,11 @@ sort_toplevel (gconstpointer tmpa, gconstpointer tmpb)
 }
 
 static void
-wireless_add_menu_item (NMDevice *device,
-                        guint32 n_devices,
-                        NMConnection *active,
-                        GtkWidget *menu,
-                        NMApplet *applet)
+wifi_add_menu_item (NMDevice *device,
+                    guint32 n_devices,
+                    NMConnection *active,
+                    GtkWidget *menu,
+                    NMApplet *applet)
 {
 	NMDeviceWifi *wdev;
 	char *text;
@@ -769,8 +770,8 @@ wireless_add_menu_item (NMDevice *device,
 	int i;
 	NMAccessPoint *active_ap = NULL;
 	GSList *connections = NULL, *all, *iter;
-	gboolean wireless_enabled = TRUE;
-	gboolean wireless_hw_enabled = TRUE;
+	gboolean wifi_enabled = TRUE;
+	gboolean wifi_hw_enabled = TRUE;
 	GSList *menu_items = NULL;  /* All menu items we'll be adding */
 	NMNetworkMenuItem *item, *active_item = NULL;
 	GtkWidget *widget;
@@ -779,19 +780,15 @@ wireless_add_menu_item (NMDevice *device,
 	aps = nm_device_wifi_get_access_points (wdev);
 
 	if (n_devices > 1) {
-		char *desc;
-
-		desc = (char *) utils_get_device_description (device);
-		if (!desc)
-			desc = (char *) nm_device_get_iface (device);
-		g_assert (desc);
+		const char *desc;
 
+		desc = nma_utils_get_device_description (device);
 		if (aps && aps->len > 1)
-			text = g_strdup_printf (_("Wireless Networks (%s)"), desc);
+			text = g_strdup_printf (_("Wi-Fi Networks (%s)"), desc);
 		else
-			text = g_strdup_printf (_("Wireless Network (%s)"), desc);
+			text = g_strdup_printf (_("Wi-Fi Network (%s)"), desc);
 	} else
-		text = g_strdup (ngettext ("Wireless Network", "Wireless Networks", aps ? aps->len : 0));
+		text = g_strdup (ngettext ("Wi-Fi Network", "Wi-Fi Networks", aps ? aps->len : 0));
 
 	widget = applet_menu_item_create_device_item_helper (device, applet, text);
 	g_free (text);
@@ -820,12 +817,12 @@ wireless_add_menu_item (NMDevice *device,
 	}
 
 	/* Notify user of unmanaged or unavailable device */
-	wireless_enabled = nm_client_wireless_get_enabled (applet->nm_client);
-	wireless_hw_enabled = nm_client_wireless_hardware_get_enabled (applet->nm_client);
+	wifi_enabled = nm_client_wireless_get_enabled (applet->nm_client);
+	wifi_hw_enabled = nm_client_wireless_hardware_get_enabled (applet->nm_client);
 	widget = nma_menu_device_get_menu_item (device, applet,
-	                                        wireless_hw_enabled ?
-	                                            (wireless_enabled ? NULL : _("wireless is disabled")) :
-	                                            _("wireless is disabled by hardware switch"));
+	                                        wifi_hw_enabled ?
+	                                            (wifi_enabled ? NULL : _("Wi-Fi is disabled")) :
+	                                            _("Wi-Fi is disabled by hardware switch"));
 	if (widget) {
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
 		gtk_widget_show (widget);
@@ -982,7 +979,7 @@ wifi_available_dont_show_cb (NotifyNotification *notify,
 		return;
 
 	g_settings_set_boolean (applet->gsettings,
-	                        PREF_SUPPRESS_WIRELESS_NETWORKS_AVAILABLE,
+	                        PREF_SUPPRESS_WIFI_NETWORKS_AVAILABLE,
 	                        TRUE);
 }
 
@@ -1065,8 +1062,8 @@ idle_check_avail_access_point_notification (gpointer datap)
 
 	applet_do_notify (applet,
 	                  NOTIFY_URGENCY_LOW,
-	                  _("Wireless Networks Available"),
-	                  _("Use the network menu to connect to a wireless network"),
+	                  _("Wi-Fi Networks Available"),
+	                  _("Use the network menu to connect to a Wi-Fi network"),
 	                  "nm-device-wireless",
 	                  "dont-show",
 	                  _("Don't show this message again"),
@@ -1080,12 +1077,12 @@ queue_avail_access_point_notification (NMDevice *device)
 {
 	struct ap_notification_data *data;
 
-	data = g_object_get_data (G_OBJECT (device), "notify-wireless-avail-data");	
+	data = g_object_get_data (G_OBJECT (device), "notify-wifi-avail-data");	
 	if (data->id != 0)
 		return;
 
 	if (g_settings_get_boolean (data->applet->gsettings,
-	                            PREF_SUPPRESS_WIRELESS_NETWORKS_AVAILABLE))
+	                            PREF_SUPPRESS_WIFI_NETWORKS_AVAILABLE))
 		return;
 
 	data->id = g_timeout_add_seconds (3, idle_check_avail_access_point_notification, data);
@@ -1150,7 +1147,7 @@ free_ap_notification_data (gpointer user_data)
 }
 
 static void
-wireless_device_added (NMDevice *device, NMApplet *applet)
+wifi_device_added (NMDevice *device, NMApplet *applet)
 {
 	NMDeviceWifi *wdev = NM_DEVICE_WIFI (device);
 	const GPtrArray *aps;
@@ -1173,7 +1170,7 @@ wireless_device_added (NMDevice *device, NMApplet *applet)
 	                  G_CALLBACK (access_point_removed_cb),
 	                  applet);
 
-	/* Now create the per-device hooks for watching for available wireless
+	/* Now create the per-device hooks for watching for available wifi
 	 * connections.
 	 */
 	data = g_new0 (struct ap_notification_data, 1);
@@ -1188,7 +1185,7 @@ wireless_device_added (NMDevice *device, NMApplet *applet)
 	                       G_CALLBACK (on_new_connection),
 	                       data);
 	data->new_con_id = id;
-	g_object_set_data_full (G_OBJECT (wdev), "notify-wireless-avail-data",
+	g_object_set_data_full (G_OBJECT (wdev), "notify-wifi-avail-data",
 	                        data, free_ap_notification_data);
 
 	queue_avail_access_point_notification (device);
@@ -1241,11 +1238,11 @@ update_active_ap (NMDevice *device, NMDeviceState state, NMApplet *applet)
 }
 
 static void
-wireless_device_state_changed (NMDevice *device,
-                               NMDeviceState new_state,
-                               NMDeviceState old_state,
-                               NMDeviceStateReason reason,
-                               NMApplet *applet)
+wifi_device_state_changed (NMDevice *device,
+                           NMDeviceState new_state,
+                           NMDeviceState old_state,
+                           NMDeviceStateReason reason,
+                           NMApplet *applet)
 {
 	NMAccessPoint *new = NULL;
 	char *msg;
@@ -1260,7 +1257,7 @@ wireless_device_state_changed (NMDevice *device,
 		return;
 
 	esc_ssid = get_ssid_utf8 (new);
-	msg = g_strdup_printf (_("You are now connected to the wireless network '%s'."), esc_ssid);
+	msg = g_strdup_printf (_("You are now connected to the Wi-Fi network '%s'."), esc_ssid);
 	applet_do_notify_with_pref (applet, _("Connection Established"),
 	                            msg, "nm-device-wireless",
 	                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
@@ -1269,11 +1266,11 @@ wireless_device_state_changed (NMDevice *device,
 }
 
 static GdkPixbuf *
-wireless_get_icon (NMDevice *device,
-                   NMDeviceState state,
-                   NMConnection *connection,
-                   char **tip,
-                   NMApplet *applet)
+wifi_get_icon (NMDevice *device,
+               NMDeviceState state,
+               NMConnection *connection,
+               char **tip,
+               NMApplet *applet)
 {
 	NMSettingConnection *s_con;
 	NMAccessPoint *ap;
@@ -1291,16 +1288,16 @@ wireless_get_icon (NMDevice *device,
 
 	switch (state) {
 	case NM_DEVICE_STATE_PREPARE:
-		*tip = g_strdup_printf (_("Preparing wireless network connection '%s'..."), id);
+		*tip = g_strdup_printf (_("Preparing Wi-Fi network connection '%s'..."), id);
 		break;
 	case NM_DEVICE_STATE_CONFIG:
-		*tip = g_strdup_printf (_("Configuring wireless network connection '%s'..."), id);
+		*tip = g_strdup_printf (_("Configuring Wi-Fi network connection '%s'..."), id);
 		break;
 	case NM_DEVICE_STATE_NEED_AUTH:
-		*tip = g_strdup_printf (_("User authentication required for wireless network '%s'..."), id);
+		*tip = g_strdup_printf (_("User authentication required for Wi-Fi network '%s'..."), id);
 		break;
 	case NM_DEVICE_STATE_IP_CONFIG:
-		*tip = g_strdup_printf (_("Requesting a wireless network address for '%s'..."), id);
+		*tip = g_strdup_printf (_("Requesting a Wi-Fi network address for '%s'..."), id);
 		break;
 	case NM_DEVICE_STATE_ACTIVATED:
 		if (ap) {
@@ -1310,23 +1307,23 @@ wireless_get_icon (NMDevice *device,
 			strength = CLAMP (strength, 0, 100);
 
 			if (strength > 80)
-				pixbuf = nma_icon_check_and_load ("nm-signal-100", &applet->wireless_100_icon, applet);
+				pixbuf = nma_icon_check_and_load ("nm-signal-100", &applet->wifi_100_icon, applet);
 			else if (strength > 55)
-				pixbuf = nma_icon_check_and_load ("nm-signal-75", &applet->wireless_75_icon, applet);
+				pixbuf = nma_icon_check_and_load ("nm-signal-75", &applet->wifi_75_icon, applet);
 			else if (strength > 30)
-				pixbuf = nma_icon_check_and_load ("nm-signal-50", &applet->wireless_50_icon, applet);
+				pixbuf = nma_icon_check_and_load ("nm-signal-50", &applet->wifi_50_icon, applet);
 			else if (strength > 5)
-				pixbuf = nma_icon_check_and_load ("nm-signal-25", &applet->wireless_25_icon, applet);
+				pixbuf = nma_icon_check_and_load ("nm-signal-25", &applet->wifi_25_icon, applet);
 			else
-				pixbuf = nma_icon_check_and_load ("nm-signal-00", &applet->wireless_00_icon, applet);
+				pixbuf = nma_icon_check_and_load ("nm-signal-00", &applet->wifi_00_icon, applet);
 
 			ssid = get_ssid_utf8 (ap);
-			*tip = g_strdup_printf (_("Wireless network connection '%s' active: %s (%d%%)"),
+			*tip = g_strdup_printf (_("Wi-Fi network connection '%s' active: %s (%d%%)"),
 			                        id, ssid, strength);
 			g_free (ssid);
 		} else {
-			pixbuf = nma_icon_check_and_load ("nm-signal-00", &applet->wireless_00_icon, applet);
-			*tip = g_strdup_printf (_("Wireless network connection '%s' active"), id);
+			pixbuf = nma_icon_check_and_load ("nm-signal-00", &applet->wifi_00_icon, applet);
+			*tip = g_strdup_printf (_("Wi-Fi network connection '%s' active"), id);
 		}
 		break;
 	default:
@@ -1337,7 +1334,7 @@ wireless_get_icon (NMDevice *device,
 }
 
 static gboolean
-wireless_dialog_close (gpointer user_data)
+wifi_dialog_close (gpointer user_data)
 {
 	GtkWidget *dialog = GTK_WIDGET (user_data);
 
@@ -1346,9 +1343,9 @@ wireless_dialog_close (gpointer user_data)
 }
 
 static void
-wireless_dialog_destroyed (gpointer data, GObject *dialog_ptr)
+wifi_dialog_destroyed (gpointer data, GObject *dialog_ptr)
 {
-	/* remove the idle function; for not to call wireless_dialog_close() on invalid pointer */
+	/* remove the idle function; for not to call wifi_dialog_close() on invalid pointer */
 	g_idle_remove_by_data (dialog_ptr);
 }
 
@@ -1357,12 +1354,12 @@ nag_dialog_response_cb (GtkDialog *nag_dialog,
                         gint response,
                         gpointer user_data)
 {
-	NMAWifiDialog *wireless_dialog = NMA_WIFI_DIALOG (user_data);
+	NMAWifiDialog *wifi_dialog = NMA_WIFI_DIALOG (user_data);
 
 	if (response == GTK_RESPONSE_NO) {  /* user opted not to correct the warning */
-		nma_wifi_dialog_set_nag_ignored (wireless_dialog, TRUE);
-		g_idle_add (wireless_dialog_close, wireless_dialog);
-		g_object_weak_ref (G_OBJECT (wireless_dialog), wireless_dialog_destroyed, NULL);
+		nma_wifi_dialog_set_nag_ignored (wifi_dialog, TRUE);
+		g_idle_add (wifi_dialog_close, wifi_dialog);
+		g_object_weak_ref (G_OBJECT (wifi_dialog), wifi_dialog_destroyed, NULL);
 	}
 }
 
@@ -1405,9 +1402,9 @@ activate_new_cb (NMClient *client,
 }
 
 static void
-wireless_dialog_response_cb (GtkDialog *foo,
-                             gint response,
-                             gpointer user_data)
+wifi_dialog_response_cb (GtkDialog *foo,
+                         gint response,
+                         gpointer user_data)
 {
 	NMAWifiDialog *dialog = NMA_WIFI_DIALOG (foo);
 	NMApplet *applet = NM_APPLET (user_data);
@@ -1590,7 +1587,7 @@ get_secrets_dialog_response_cb (GtkDialog *foo,
 		g_set_error (&error,
 		             NM_SECRET_AGENT_ERROR,
 		             NM_SECRET_AGENT_ERROR_INTERNAL_ERROR,
-		             "%s.%d (%s): couldn't get connection from wireless dialog.",
+		             "%s.%d (%s): couldn't get connection from Wi-Fi dialog.",
 		             __FILE__, __LINE__, __func__);
 		goto done;
 	}
@@ -1665,7 +1662,7 @@ done:
 }
 
 static gboolean
-wireless_get_secrets (SecretsRequest *req, GError **error)
+wifi_get_secrets (SecretsRequest *req, GError **error)
 {
 	NMWifiInfo *info = (NMWifiInfo *) req;
 
@@ -1696,12 +1693,12 @@ applet_device_wifi_get_class (NMApplet *applet)
 	if (!dclass)
 		return NULL;
 
-	dclass->new_auto_connection = wireless_new_auto_connection;
-	dclass->add_menu_item = wireless_add_menu_item;
-	dclass->device_added = wireless_device_added;
-	dclass->device_state_changed = wireless_device_state_changed;
-	dclass->get_icon = wireless_get_icon;
-	dclass->get_secrets = wireless_get_secrets;
+	dclass->new_auto_connection = wifi_new_auto_connection;
+	dclass->add_menu_item = wifi_add_menu_item;
+	dclass->device_added = wifi_device_added;
+	dclass->device_state_changed = wifi_device_state_changed;
+	dclass->get_icon = wifi_get_icon;
+	dclass->get_secrets = wifi_get_secrets;
 	dclass->secrets_request_size = sizeof (NMWifiInfo);
 
 	return dclass;
